@@ -1,7 +1,7 @@
 ### Seed functions for random number generators.
 
 comm.set.seed <- function(seed, diff = FALSE, state = NULL,
-    comm = .SPMD.CT$comm){
+    comm = .pbd_env$SPMD.CT$comm){
   if(exists(".lec.Random.seed.table", envir = .GlobalEnv)){
     comm.end.seed(comm)
   }
@@ -19,6 +19,7 @@ comm.set.seed <- function(seed, diff = FALSE, state = NULL,
     name <- "0"
   }
 
+  invisible(eval(.lec.old.kind <- RNGkind(), envir = .GlobalEnv))
   invisible(eval(.lec.SetPackageSeed(seed), envir = .GlobalEnv))
   invisible(eval(.lec.CreateStream(names), envir = .GlobalEnv))
   if(! is.null(state)){
@@ -28,26 +29,34 @@ comm.set.seed <- function(seed, diff = FALSE, state = NULL,
   invisible()
 } # End of comm.set.seed().
 
-comm.end.seed <- function(comm = .SPMD.CT$comm){
+comm.end.seed <- function(comm = .pbd_env$SPMD.CT$comm){
   name <- get(".lec.Random.seed.table", envir = .GlobalEnv)$name
+  old.kind <- try(get(".lec.old.kind", envir = .GlobalEnv), silent = TRUE)
+  if(class(old.kind) == "try-error"){
+    old.kind <- RNGkind()
+  }
 
   if(! is.null(name)){
-    invisible(eval(.lec.CurrentStreamEnd(), envir = .GlobalEnv))
+    invisible(eval(.lec.CurrentStreamEnd(old.kind), envir = .GlobalEnv))
     invisible(eval(.lec.DeleteStream(name), envir = .GlobalEnv))
-    rm.list <- c(".lec.Random.seed.table", ".Random.seed")
-    invisible(eval(rm(list = rm.list, envir = .GlobalEnv)))
+    # rm.list <- c(".lec.Random.seed.table", ".Random.seed")
+    # invisible(eval(rm(list = rm.list, envir = .GlobalEnv)))
   }
 
   invisible()
 } # End of comm.end.seed().
 
-comm.reset.seed <- function(comm = .SPMD.CT$comm){
+comm.reset.seed <- function(comm = .pbd_env$SPMD.CT$comm){
   seed.table <- get(".lec.Random.seed.table", envir = .GlobalEnv)
-
   if(is.null(seed.table)){
     comm.stop("seed.table is not found.", comm = comm)
   }
 
+  old.kind <- try(get(".lec.old.kind", envir = .GlobalEnv), silent = TRUE)
+  if(class(old.kind) == "try-error"){
+    old.kind <- RNGkind()
+  }
+
   if(length(seed.table$name) == comm.size(comm)){
     name <- seed.table$name[comm.rank(comm) + 1]
   } else if(length(seed.table$name) == 1){
@@ -56,19 +65,23 @@ comm.reset.seed <- function(comm = .SPMD.CT$comm){
     comm.stop("seed.table is incorrect.", comm = comm)
   }
 
-  invisible(eval(.lec.CurrentStreamEnd(), envir = .GlobalEnv))
+  invisible(eval(.lec.CurrentStreamEnd(old.kind), envir = .GlobalEnv))
   invisible(eval(.lec.ResetStartStream(name), envir = .GlobalEnv))
   invisible(eval(.lec.CurrentStream(name), envir = .GlobalEnv))
   invisible()
 } # End of comm.reset.seed().
 
-comm.seed.state <- function(comm = .SPMD.CT$comm){
+comm.seed.state <- function(comm = .pbd_env$SPMD.CT$comm){
   seed.table <- get(".lec.Random.seed.table", envir = .GlobalEnv)
-
   if(is.null(seed.table)){
     comm.stop("seed.table is not found.", comm = comm)
   }
 
+  old.kind <- try(get(".lec.old.kind", envir = .GlobalEnv), silent = TRUE)
+  if(class(old.kind) == "try-error"){
+    old.kind <- RNGkind()
+  }
+
   if(length(seed.table$name) == comm.size(comm)){
     name <- seed.table$name[comm.rank(comm) + 1]
   } else if(length(seed.table$name) == 1){
@@ -78,7 +91,7 @@ comm.seed.state <- function(comm = .SPMD.CT$comm){
   }
 
   ### Terminate the stream first to get the current state.
-  invisible(.lec.CurrentStreamEnd())
+  invisible(.lec.CurrentStreamEnd(old.kind))
   ret <- .lec.GetState(name)
 
   ### Set the state back to stream (pretend as nothing happens).
