@@ -4,14 +4,14 @@
 ###   "pbd*/etc${R_ARCH}/Makconf".
 get.lib <- function(arg, arch, package = "pbdPROF"){
   file.name <- paste("./etc", arch, "/Makeconf", sep = "")
-  file.path <- tools:::file_path_as_absolute(
+  file.path <- tools::file_path_as_absolute(
                  system.file(file.name, package = package))
   ret <- scan(file.path, what = character(), sep = "\n", quiet = TRUE)
 
   id <- grep(paste("^", arg, " = ", sep = ""), ret)
   if(length(id) > 0){
     lib.file <- gsub(paste("^", arg, " = (.*)", sep = ""), "\\1", ret[id[1]])
-    file.path <- tools:::file_path_as_absolute(
+    file.path <- tools::file_path_as_absolute(
                    system.file(lib.file, package = package))
     cat(file.path)
   } else{
